// Run with "--env production" to get production optimized output

// Load plugins
var gulp = require('gulp'),
  gulpif = require('gulp-if'),
  sass = require('gulp-sass'),
  sourcemaps = require('gulp-sourcemaps'),
  notify = require('gulp-notify'),
  minimist = require('minimist'),
  config = {
    cssPath: '../css',
    fontsPath: '../fonts',
    sassPath: './sass',
    bowerDir: './bower_components'
  },
  knownOptions = {
    string: 'env',
    default: { env: process.env.NODE_ENV || 'development' }
  },
  options = minimist(process.argv.slice(2), knownOptions);

// Pre-process CSS
gulp.task('css', function() {
  return gulp.src(config.sassPath + '/*.scss')
    //.pipe(gulpif(options.env !== 'production', sourcemaps.init()))
    .pipe(sass({
      outputStyle:gulpif(options.env !== 'production', 'nested', 'compressed'),
      includePaths:[
        config.sassPath
      ]})
      .on("error", notify.onError(function (error) {
        return "Error: " + error.message;
      })))
    .pipe(gulpif(options.env !== 'production', sourcemaps.write('./maps')))
    .pipe(gulp.dest(config.cssPath));
});

// Rerun the task when a file changes
gulp.task('watch', function() {
  gulp.watch(config.sassPath + '/**/*.scss', ['css']);
});

// Default task: run all other tasks in the correct order
gulp.task('default', ['css']);
