<?php

/**
 * @file
 * Contains \Drupal\drd\Agent\Action\BaseInterface.
 */

namespace Drupal\drd\Agent\Action;

use Drupal\drd\Crypt\BaseMethodInterface;

/**
 * Defines an interface for Remote DRD Action Code.
 */
interface BaseInterface {

  /**
   * Callback to set the current user to uid=1 to make sure we have sufficient
   * permissions.
   */
  public static function promoteUser();

  /**
   * @param string $uuid
   * @return BaseMethodInterface
   */
  public static function getCryptInstance($uuid);

  /**
   * @return array
   */
  public static function getArguments();

  /**
   * @return bool
   */
  public static function getDebugMode();

  /**
   * @var bool $debugMode
   */
  public static function setDebugMode($debugMode);

  /**
   * Internal watchdog replacement which only reports to watchdog if debugging
   * is switched on by the remote DRD dashboard.
   *
   * @param string $message
   *   Message of the watchdog report.
   * @param array $variables
   *   Parameters for the watchdog report.
   * @param int $severity
   *   Severity of the watchdog report.
   * @param string $link
   *   Optional link associated with the watchdog report.
   */
  public static function watchdog($message, $variables = array(), $severity = 5, $link = NULL);

  /**
   * @param string $ott
   * @param string $config
   * @return bool
   */
  public static function ott($ott, $config);

  /**
   * @return array
   */
  public function execute();

}
