<?php

/**
 * @file
 * Contains \Drupal\drd\Command\BaseDomain.
 */

namespace Drupal\drd\Command;

use Drupal\Console\Core\Style\DrupalStyle;
use Drupal\drd\Plugin\Action\BaseEntityRemote;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class BaseDomain.
 *
 * @package Drupal\drd
 */
abstract class BaseDomain extends Base {

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->addOption(
        'domain-id',
        NULL,
        InputOption::VALUE_OPTIONAL,
        $this->trans('commands.drd.actions.remote.arguments.domain-id')
      );
  }

  /**
   * {@inheritdoc}
   */
  protected function execute(InputInterface $input, OutputInterface $output) {
    $action = parent::execute($input, $output);
    $io = new DrupalStyle($input, $output);

    if (empty($action) || !($action instanceof BaseEntityRemote)) {
      $io->error('No valid remote action!');
      return;
    }

    $domain_id = $input->getOption('domain-id');
    if ($domain_id) {
      $domain = \Drupal::entityTypeManager()
          ->getStorage('drd_domain')
          ->load($domain_id);
      $domains = empty($domain) ? [] : [$domain];
    }
    else {
      $domains = \Drupal::entityTypeManager()
        ->getStorage('drd_domain')
        ->loadByProperties([
          'status' => 1,
          'installed' => 1,
        ]);
    }
    if (empty($domains)) {
      $io->error('No domain found!');
      return;
    }
    $io->info('Executing ' . $action->getPluginDefinition()['label']);
    foreach ($domains as $domain) {
      /** @var \Drupal\drd\Entity\DomainInterface $domain */
      $io->info('- on ' . $domain->getName());
      if ($action->executeAction($domain) !== FALSE) {
        $response = $action->getResponse();
        if (is_array($response) && !empty($response['output'])) {
          $io->info('  ' . $response['output']);
        }
        $io->success('  ok!');
      }
      else {
        $io->error('  failure!');
      }
    }

    $io->info('Completed!');
  }

}
