<?php

/**
 * @file
 * Contains \Drupal\drd\Command\BaseHost.
 */

namespace Drupal\drd\Command;

use Drupal\Console\Core\Style\DrupalStyle;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class BaseHost.
 *
 * @package Drupal\drd
 */
abstract class BaseHost extends Base {

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->addOption(
        'host-id',
        'hid',
        InputOption::VALUE_OPTIONAL,
        $this->trans('commands.drd.actions.local.arguments.host-id')
      );
  }

  /**
   * {@inheritdoc}
   */
  protected function execute(InputInterface $input, OutputInterface $output) {
    $action = parent::execute($input, $output);
    $io = new DrupalStyle($input, $output);

    if (empty($action) || !($action instanceof \Drupal\drd\Plugin\Action\BaseHost)) {
      $io->error('No valid local action!');
      return;
    }

    $host_id = $input->getOption('host-id');
    if ($host_id) {
      $hosts = [
        \Drupal::entityTypeManager()
          ->getStorage('drd_host')
          ->load($host_id)
      ];
    }
    else {
      $hosts = \Drupal::entityTypeManager()
        ->getStorage('drd_host')
        ->loadByProperties([
          'status' => 1,
        ]);
    }
    if (empty($hosts)) {
      $io->warning('No host found!');
      return;
    }
    $io->info('Executing ' . $action->getPluginDefinition()['label']);
    foreach ($hosts as $host) {
      /** @var \Drupal\drd\Entity\HostInterface $host */
      $io->info('- on ' . $host->getName());
      if ($action->executeAction($host)) {
        $io->success('  ok!');
      }
      else {
        $io->error('  failure!');
      }
    }

    $io->info('Completed!');
  }

}
