<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\Library.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\Core\Annotation\Action;
use Drupal\Core\Annotation\Translation;
use Drupal\Core\Url;
use Drupal\drd\HttpRequest;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Library' action.
 *
 * @Action(
 *  id = "drd_action_library",
 *  label = @Translation("Library"),
 *  type = "drd_domain",
 * )
 */
class Library extends BaseEntityRemote implements BaseConfigurableInterface {

  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->arguments['source'] = 'official';
  }

  /**
   * @inheritdoc
   */
  public function executeAction($domain) {
    static $buildCompleted;

    if ($this->arguments['source'] == 'official') {
      $this->arguments['url'] = 'http://cgit.drupalcode.org/drd/plain/build/drd.phar?h=' . HttpRequest::getVersion();
    }
    else {
      if (empty($buildCompleted)) {
        // Re-build PHAR
        \Drupal::service('drd.library.build')->build($this->arguments);
        $buildCompleted = TRUE;
      }
    }

    return parent::executeAction($domain);
  }

  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['drd_action_library_source'] = array(
      '#type' => 'select',
      '#title' => t('Mode'),
      '#default_value' => 'official',
      '#options' => [
        'official' => t('Published version from drupal.org'),
        'local' => t('Local development version'),
        'none' => t('None, update build only'),
      ],
    );
    return $form;
  }

  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {}

  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->arguments['source'] = $form_state->getValue('drd_action_library_source');
  }

}
