<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Auth\UsernamePassword.
 */

namespace Drupal\drd\Plugin\Auth;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\drd\Annotation\Auth;

/**
 * Plugin implementation of the 'username_password' DRD authentication.
 *
 * @Auth(
 *   id = "username_password",
 *   label = @Translation("DRD Auth: Username and Password"),
 *   description = @Translation("TBD")
 * )
 */
class UsernamePassword extends Base {
  use StringTranslationTrait;

  /**
   * @inheritDoc
   */
  public function storeSettingRemotely() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array &$form, array $condition) {
    $form['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#default_value' => '',
      '#states' => [
        'required' => $condition,
      ],
    ];
    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#default_value' => '',
      '#states' => [
        'required' => $condition,
      ],
    ];
  }

  /**
   * @inheritDoc
   */
  public function settingsFormValues(FormStateInterface $form_state) {
    return [
      'username' => $form_state->getValue('username'),
      'password' => $form_state->getValue('password'),
    ];
  }

}
