<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\views\field\UpdateStatus.
 */

namespace Drupal\drd\Plugin\views\field;

use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\drd\UpdateProcessor;
use Drupal\views\Annotation\ViewsField;
use Drupal\views\Plugin\views\field\Standard;
use Drupal\views\ResultRow;

/**
 * A handler to display the project update status.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("drd_update_status")
 */
class UpdateStatus extends Standard {
  /**
   * @inheritDoc
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    $this->realField = 'updatestatus';
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $statuses = UpdateProcessor::getStatuses();
    $status = $this->getValue($values);
    if (empty($status)) {
      $status = UPDATE_NOT_SUPPORTED;
    }
    $type = $statuses['status'][$status]['type'];
    $title = $statuses['type'][$type]['title'];

    $release = $values->_entity;
    if ($release instanceof \Drupal\drd\Entity\ReleaseInterface) {
      $link_project = \Drupal::linkGenerator()
        ->generate($this->t('Project'), $release->getProjectLink());
      $major = $release->getMajor();
      $recommended = $major->getRecommendedRelease();
      $output = '<div class="project">' . $link_project . '</div>' .
        '<div class="label">' . $title . '</div>';
      if (!empty($recommended) && $recommended->id() != $release->id()) {
        $link_recommended = \Drupal::linkGenerator()
          ->generate($recommended->getVersion(), $recommended->getReleaseLink());
        $link_download = \Drupal::linkGenerator()
          ->generate($this->t('Download'), $recommended->getDownloadLink());
        $output .=
          '<div class="release">' . $link_recommended . '</div>' .
          '<div class="download">' . $link_download . '</div>';
      }
    }
    else {
      $output = substr($title, 0, 3);
    }

    return Markup::create('<div class="drd-update-status ' . $type . '">' . $output . '</div>');
  }

}
