<?php

/**
 * @file
 * Contains \Drupal\drd\QueueManager.
 */

namespace Drupal\drd;

use Drupal\Core\Queue\QueueFactory;
use Drupal\Core\Queue\QueueInterface;

/**
 * Easy access to the DRD queue.
 */
class QueueManager {

  /**
   * @return QueueInterface
   */
  private function getQueue() {
    /** @var QueueFactory $queue_factory */
    $queue_factory = \Drupal::service('queue');
    /** @var QueueInterface $queue */
    return $queue_factory->get('drd');
  }

  /**
   * @return integer
   */
  public function countItems() {
    return $this->getQueue()->numberOfItems();
  }

  /**
   * @param \Drupal\drd\Plugin\Action\Base $action
   * @param \Drupal\drd\Entity\DomainInterface $entity
   */
  public function createItem($action, $entity = NULL) {
    $item = new \stdClass();
    $item->action = $action;
    $item->entity = $entity;
    $item->arguments = $action->getArguments();
    $this->getQueue()->createItem($item);
  }

  /**
   * @param \Drupal\drd\Plugin\Action\Base $action
   * @param \Drupal\drd\Entity\DomainInterface[] $entities
   */
  public function createItems($action, $entities) {
    foreach ($entities as $entity) {
      $this->createItem($action, $entity);
    }
  }

}
