<?php

namespace Drupal\drd;

use Drupal\Component\Serialization\Json;
use Drupal\drd\Entity\Domain;

/**
 * Class SshCommand.
 *
 * @package Drupal\drd
 */
class SshCommand {

  /**
   * @var Domain
   */
  protected $domain;

  /**
   * @var Resource
   */
  protected $connection;

  /**
   * @var string
   */
  protected $command = '';

  /**
   * @var string
   */
  protected $output = '';

  /**
   * @var string
   */
  protected $error = '';

  /**
   * @param Domain $domain
   * @return $this
   */
  public function setDomain($domain) {
    $this->domain = $domain;
    $this->initConnection();
    return $this;
  }

  /**
   * @param string $command
   * @return $this
   */
  public function setCommand($command) {
    $this->command = $command;
    return $this;
  }

  /**
   * @return string
   */
  public function getOutput() {
    return $this->output;
  }

  /**
   * @return string
   */
  public function getJsonOutput() {
    try {
      return Json::decode($this->output);
    }
    catch (\Exception $ex) {
      return FALSE;
    }
  }

  /**
   * @return bool
   */
  public function execute() {
    $stream = ssh2_exec($this->connection, $this->command);
    stream_set_blocking($stream, true);
    $this->output = stream_get_contents($stream);
    $this->error = stream_get_contents(ssh2_fetch_stream($stream, SSH2_STREAM_STDERR));
    if (!empty($this->error)) {
      // TODO: Let's store the message with the domain
      return FALSE;
    }
    return TRUE;
  }

  private function initConnection() {
    if (!function_exists('ssh2_connect')) {
      throw new \Exception('SSH2 library for PHP is not available.');
    }

    if (empty($this->domain->getCore()->getHost()->get('ssh2')->value)) {
      throw new \Exception('SSH for this domain is disabled.');
    }

    $settings = $this->domain->getCore()->getHost()->getSshSettings();

    if (!empty($settings['host'])) {
      $host = $settings['host'];
    }
    else {
      $host = $this->domain->get('domain');
    }

    $this->connection = @ssh2_connect($host, $settings['port']);
    if (!$this->connection) {
      throw new \Exception('SSH connection not possible.');
    }
    switch ($settings['auth']['mode']) {
      case 1:
        $success = @ssh2_auth_password(
          $this->connection,
          $settings['auth']['username'],
          $settings['auth']['password']
        );
        break;

      case 2:
        $success = @ssh2_auth_pubkey_file(
          $this->connection,
          $settings['auth']['username'],
          $settings['auth']['file_public_key'],
          $settings['auth']['file_private_key'],
          $settings['auth']['key_secret']
        );
        break;

      case 3:
        if (function_exists('ssh2_auth_agent')) {
          $success = @ssh2_auth_agent(
            $this->connection,
            $settings['auth']['username']
          );
        }
        break;

    }
    if (empty($success)) {
      throw new \Exception('SSH authentication failed.');
    }
  }

}
